#
# spec file for package ghc-base-compat
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name base-compat
Name:           ghc-%{pkg_name}
Version:        0.10.5
Release:        1.2
Summary:        A compatibility layer for base
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-unix-devel

%description
Provides functions available in later versions of 'base' to a wider range of
compilers, without requiring you to use CPP pragmas in your code. See the
<https://github.com/haskell-compat/base-compat/blob/master/base-compat/README.markdown
README> for what is covered. Also see the
<https://github.com/haskell-compat/base-compat/blob/master/base-compat/CHANGES.markdown
changelog> for recent changes.

Note that 'base-compat' does not add any orphan instances. There is a separate
package, '<http://hackage.haskell.org/package/base-orphans base-orphans>', for
that.

In addition, 'base-compat' does not backport any data types or type classes.
See
'<https://github.com/haskell-compat/base-compat/blob/master/base-compat/README.markdown#data-types-and-type-classes
this section of the README>' for more info.

'base-compat' is designed to have zero dependencies. For a version of
'base-compat' that depends on compatibility libraries for a wider support
window, see the '<http://hackage.haskell.org/package/base-compat-batteries
base-compat-batteries>' package. Most of the modules in this library have the
same names as in 'base-compat-batteries' to make it easier to switch between
the two. There also exist versions of each module with the suffix '.Repl',
which are distinct from anything in 'base-compat-batteries', to allow for
easier use in GHCi.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.markdown README.markdown

%changelog
* Fri Oct 19 2018 psimons@suse.com
- Update base-compat to version 0.10.5.
  [#]# Changes in 0.10.5 [2018.10.18]
  - Enable `BangPatterns` in `Prelude.Compat`.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Tue Jul 17 2018 psimons@suse.com
- Update base-compat to version 0.10.4.
  [#]# Changes in 0.10.4 [2018.07.03]
  - Make more modules `Trustworthy`. In particular, fix a regression in which
    `Prelude.Compat` was inferred as `Unsafe` by explicitly marking it as
    `Trustwothy`.
  [#]# Changes in 0.10.3 [2018.07.02]
  - Backport the proper fixity for `($!)`, which was accidentally omitted in
    `base-compat-0.10.2`.
  [#]# Changes in 0.10.2 [2018.07.02]
  - Sync with `base-4.12`/GHC 8.6
  - Backport `RuntimeRep`-polymorphic versions of `($!)` and `throw` to
    `Prelude.Compat` and `Control.Exception.Compat`, respectively
    (if using `base-4.10`/GHC 8.2 or later).
  - Introduce the `Data.Functor.Contravariant.Compat` module, which reexports
    `Data.Functor.Contravariant` if using `base-4.12`/GHC 8.6 or later.
    See `Data.Functor.Contravariant.Compat` in the corresponding
    `base-compat-batteries` release for a version with a wider support window.
  [#]# Changes in 0.10.1 [2018.04.10]
  - Add `Data.List.NonEmpty.Compat`.
  - Reexport `(Data.Semigroup.<>)` from `Data.Monoid.Compat` back to `base-4.9`.
  [#]# Changes in 0.10.0 [2018.04.05]
  - Sync with `base-4.11`/GHC 8.4
  - Backport `Semigroup((<>))` to `Prelude.Compat`.
    Note that the `Semigroup` class has only been in `base` since
    `base-4.9`/GHC 8.0, so accordingly, this can only be backported back
    to GHC 8.0. If you wish to have a version of `Prelude.Compat` that backports
    `Semigroup` to older GHCs (by conditionally depending on the `semigroups`
    library), use the `Prelude.Compat` module from the `base-compat-batteries`
    package.
  - Backport `(<&>)` to `Data.Functor.Compat`
  - Backport `iterate'` to `Data.List.Compat`
  - Backport `showHFloat` to `Numeric.Compat`
  - Backport a `RuntimeRep`-polymorphic `withTypeable` function to
    `Type.Reflection.Compat`. (This is only exported on `base-4.10`/GHC 8.2.)
  - Introduce the following modules, back until the oldest version of `base`
    that can support backporting them. If you wish to use them in conjunction
    with older versions of `base`, use the `base-compat-batteries` package.
  - `Control.Monad.Fail.Compat` (back until `base-4.9`/GHC 8.0)
  - `Control.Monad.IO.Class.Compat` (back until `base-4.9`/GHC 8.0)
  - `Data.Bifunctor` (back until `base-4.8`/GHC 7.10)
  - `Data.Bifoldable` and `Data.Bitraversable` (back until `base-4.10`/GHC 8.2)
  - `Data.Functor.Compose.Compat`, `Data.Functor.Product.Compat`, and
    `Data.Functor.Sum.Compat` (back until `base-4.9`/GHC 8.0)
  - `Data.Functor.Identity.Compat` (back until `base-4.8`/GHC 7.10)
  - `Data.Semigroup.Compat` (back until `base-4.9`/GHC 8.0)
  - `Data.Void.Compat` (back until `base-4.8`/GHC 7.10)
  - `Numeric.Natural.Compat` (back until `base-4.8`/GHC 7.10)
  - Introduce versions of modules with the suffix `.Repl`. These simply reexport
    the contents of their counterparts without the `.Repl` suffix to provide
    a globally unique namespace to import from in the event one wants to import
    `base-compat` modules into GHCi. (In `base-compat-batteries`, the
    corresponding suffix is `.Repl.Batteries`.)
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 0.9.3 with cabal2obs.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 0.9.2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.9.1 revision 0 with cabal2obs.
* Tue Apr 12 2016 mimi.vx@gmail.com
- update to 0.9.1
  * Use the more efficient version of replicateM and replicateM_ introduced in base-4.9
* Wed Jan 20 2016 mimi.vx@gmail.com
- update to 0.9.0
  * Sync with base-4.9/GHC 8.0
  * Weakened RealFloat constraints on realPart, imagPart, conjugate, mkPolar, and cis
    in Data.Complex.Compat
  * Backport Foreign.ForeignPtr.Safe and Foreign.Marshal.Safe
  * Generalize filterM, forever, mapAndUnzipM, zipWithM, zipWithM_, replicateM,
    and replicateM_ in Control.Monad from Monad to Applicative
  * Backport .Unsafe.Compat modules (for Control.Monad.ST, Control.Monad.ST.Lazy,
    Foreign.ForeignPtr, and Foreign.Marshal)
  * Backport forkFinally and forkOSWithUnmask to Control.Concurrent.Compat
  * Backport Data.Functor.Const
  * Backport modifyIORef', atomicModifyIORef' and atomicWriteIORef to Data.IORef.Compat
  * Data.Ratio.{denominator,numerator} have no Integral constraint anymore
  * Backport modifySTRef' to Data.STRef.Compat
  * Export String, lines, words, unlines, and unwords to Data.String.Compat
  * Generalize Debug.Trace.{traceM, traceShowM} from Monad to Applicative
  * Backport errorWithoutStackTrace to Prelude.Compat
  * Backport unsafeFixIO and unsafeDupablePerformIO to System.IO.Unsafe.Compat
* Tue Dec 15 2015 mimi.vx@gmail.com
- initial commit
